searchNodes=[{"doc":"RingBuffer provides an Elixir ring buffer implementation based on Erlang :queue.There are other fine Elxir libraries providing implementations of ring or circular buffers. This one provides a wanted feature that the others did not provide, namely that the item that was evicted due to a put/2 call is available for inspection after completion of the put/2 call.In this implementation, put/2 returns the new RingBuffer to preserve the abilty to build pipelines and the item that was evicted as the result of the last call to put/2, if any, is available in the field :evicted.If the :size of the buffer at the time of the last call to put/2 was less than the configured :max_size, then :evicted will be nil after the call to put/2 since adding the new item did not require evicting another item.A call to take/1 will cause :evicted to be set to nil.","ref":"RingBuffer.html","title":"RingBuffer","type":"module"},{"doc":"Returns true if buffer contains no items.Parametersbuffer: the RingBuffer whose emptiness is to be testedExamplesiex&gt; RingBuffer.new(5) ...&gt; |&gt; RingBuffer.empty?() true iex&gt; RingBuffer.new(4) ...&gt; |&gt; RingBuffer.put(&quot;red&quot;) ...&gt; |&gt; RingBuffer.empty?() false","ref":"RingBuffer.html#empty?/1","title":"RingBuffer.empty?/1","type":"function"},{"doc":"Creates a new RingBuffer struct.Parametersmax_size: the max number of items in the buffer.Examplesiex&gt; RingBuffer.new(10) %RingBuffer{queue: {[], []}, max_size: 10, size: 0, evicted: nil}","ref":"RingBuffer.html#new/1","title":"RingBuffer.new/1","type":"function"},{"doc":"Returns the newest item in the buffer, or nil if the buffer is empty.Parametersbuffer: the RingBuffer whose newest item is soughtExamplesiex&gt; RingBuffer.new(3) ...&gt; |&gt; RingBuffer.put(&quot;elixir&quot;) ...&gt; |&gt; RingBuffer.put(&quot;is&quot;) ...&gt; |&gt; RingBuffer.put(&quot;the&quot;) ...&gt; |&gt; RingBuffer.put(&quot;best&quot;) ...&gt; |&gt; RingBuffer.newest() &quot;best&quot; iex&gt; RingBuffer.new(3) ...&gt; |&gt; RingBuffer.newest() nil","ref":"RingBuffer.html#newest/1","title":"RingBuffer.newest/1","type":"function"},{"doc":"Returns the oldest item in the buffer, or nil if the buffer is empty.Parametersbuffer: the RingBuffer whose oldest item is soughtExamplesiex&gt; RingBuffer.new(3) ...&gt; |&gt; RingBuffer.put(&quot;elixir&quot;) ...&gt; |&gt; RingBuffer.put(&quot;is&quot;) ...&gt; |&gt; RingBuffer.put(&quot;the&quot;) ...&gt; |&gt; RingBuffer.put(&quot;best&quot;) ...&gt; |&gt; RingBuffer.oldest() &quot;is&quot; iex&gt; RingBuffer.new(3) ...&gt; |&gt; RingBuffer.oldest() nil","ref":"RingBuffer.html#oldest/1","title":"RingBuffer.oldest/1","type":"function"},{"doc":"Adds the item to the buffer. When buffer :size is less than :max_size, the item will be added, the buffer :size will be incremented by one and :evicted will be nil. When bufffer :size is equal to :max_size, the item will be added, the buffer :size will remain at :max_size, and the oldest item in the buffer preceding the call to put/2 will be bound to :evicted.Parametersbuffer: the RingBuffer to which item is to be addeditem: the item to add to bufferExamplesiex&gt; RingBuffer.new(8) ...&gt; |&gt; RingBuffer.put(&quot;elixir&quot;) ...&gt; |&gt; RingBuffer.put(&quot;is&quot;) ...&gt; |&gt; RingBuffer.put(&quot;the&quot;) ...&gt; |&gt; RingBuffer.put(&quot;best&quot;) %RingBuffer{queue: {[&quot;best&quot;, &quot;the&quot;, &quot;is&quot;], [&quot;elixir&quot;]}, max_size: 8, size: 4, evicted: nil} iex&gt; RingBuffer.new(3) ...&gt; |&gt; RingBuffer.put(&quot;elixir&quot;) ...&gt; |&gt; RingBuffer.put(&quot;is&quot;) ...&gt; |&gt; RingBuffer.put(&quot;the&quot;) ...&gt; |&gt; RingBuffer.put(&quot;best&quot;) %RingBuffer{queue: {[&quot;best&quot;, &quot;the&quot;], [&quot;is&quot;]}, max_size: 3, size: 3, evicted: &quot;elixir&quot;}","ref":"RingBuffer.html#put/2","title":"RingBuffer.put/2","type":"function"},{"doc":"Takes the oldest item from the buffer, returning a 2-element tuple containing the taken item and the new buffer. For a non-empty buffer, the taken item will be non-nil and the :size of the buffer will be decremented by one. For an empty buffer, the taken item will be nil and the :size of the buffer will continue to be zero.Parametersbuffer: the RingBuffer from which an item is to be takenExamplesiex&gt; RingBuffer.new(3) ...&gt; |&gt; RingBuffer.put(&quot;elixir&quot;) ...&gt; |&gt; RingBuffer.put(&quot;is&quot;) ...&gt; |&gt; RingBuffer.put(&quot;the&quot;) ...&gt; |&gt; RingBuffer.put(&quot;best&quot;) ...&gt; |&gt; RingBuffer.take() {&quot;is&quot;, %RingBuffer{queue: {[&quot;best&quot;], [&quot;the&quot;]}, max_size: 3, size: 2, evicted: nil}} iex&gt; RingBuffer.new(3) ...&gt; |&gt; RingBuffer.take() {nil, %RingBuffer{queue: {[], []}, max_size: 3, size: 0, evicted: nil}}","ref":"RingBuffer.html#take/1","title":"RingBuffer.take/1","type":"function"},{"doc":"Type that represents RingBuffer struct with `:maxsize` as integer, `:size` as integer, `:queue` as tuple and `:evicted` as any","ref":"RingBuffer.html#t:t/0","title":"RingBuffer.t/0","type":"type"}]